
## Release Notes

**v1.3.2 - December 3, 2020**

* **fixed** image wells not getting imported correctly

**v1.3.1 - June 25, 2020**

* **fixed** small Python 2 to 3 issues

**v1.3.0 - May 25, 2020**

* Now compatible with Python 3.*
